Documentation
¶
Index ¶
Constants ¶
const ErrorThreshold = 300
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type APIClient ¶
func (*APIClient) ClearLooseCookies ¶
func (client *APIClient) ClearLooseCookies()
type BodyParams ¶
BodyParams is a map of strings, with a string key, used to store the parameters of the request body.
type Headers ¶
Headers is a map of strings, with a string key, used to store the parameters of the request headers.
type Request ¶
type Request struct {
URL string
Method string
EndPoint string
EndPointParams URLParams
DynamicEndPoint bool
Headers Headers
Path []string
Query url.Values
Body BodyParams
BodyJSON io.Reader
Auth Auth
BodyText string
Cookies []*http.Cookie
}
Request is a struct used to store the collective data of the API/Web Request used by Do() and Build().
Click to show internal directories.
Click to hide internal directories.